@@ -22,10 +22,23 @@ rglwidget <- local({
   if (!is.na(reuse))
     reuseDF <<- attr(x, "reuse")
 
-  if (!is.null(controllers))
-    x$players = controllers
+  if (inherits(controllers, "rglPlayer") && is.na(controllers$x$sceneId)) {
+    x$players <- controllers$elementId
+    if (!is.null(elementId))
+      controllers$x$sceneId <- elementId
+  } else if (inherits(controllers, "shiny.tag.list")) {
+    x$players <- character()
+    for (i in seq_along(controllers)) {
+      if (inherits(controllers[[i]], "rglPlayer") && is.na(controllers[[i]]$x$sceneId)) {
+        x$players <- c(x$players, controllers[[i]]$elementId)
+        if (!is.null(elementId))
+          controllers[[i]]$x$sceneId <- elementId
+      }
+    }
+  } else if (!is.null(controllers))
+    x$players <- controllers
   # create widget
-  structure(htmlwidgets::createWidget(
+  result <- structure(htmlwidgets::createWidget(
     name = 'rglWebGL',
     x = x,
     width = width,
@@ -34,6 +47,13 @@ rglwidget <- local({
     elementId = elementId,
     ...
   ), rglReuse = attr(x, "reuse"))
+  if (inherits(controllers, "shiny.tag.list")) {
+    controllers[[length(controllers) + 1]] <- result
+    controllers
+  } else if (inherits(controllers, "rglPlayer")) {
+    browsable(tagList(controllers, result))
+  } else
+    result
   }
 })
 
